from setuptools import setup, find_packages


setup(
    name='fibonacci_cisco',
    version='0.1.2',
    license='MIT',
    author="example example",
    author_email='email@example.com',
    packages=find_packages('src'),
    package_dir={'': 'src'},
    url="",
    keywords='example project',
    install_requires=[],

)